@@ -2,7 +2,7 @@ import unittest
 from libpysal.examples import load_example
 import geopandas as gpd
 import numpy as np
-from segregation.aspatial import Entropy
+from segregation.singlegroup import Entropy
 
 
 class Entropy_Tester(unittest.TestCase):
@@ -10,7 +10,7 @@ class Entropy_Tester(unittest.TestCase):
         s_map = gpd.read_file(load_example("Sacramento1").get_path("sacramentot2.shp"))
         df = s_map[['geometry', 'HISP', 'TOT_POP']]
         index = Entropy(df, 'HISP', 'TOT_POP')
-        np.testing.assert_almost_equal(index.statistic, 0.09459760633014454)
+        np.testing.assert_almost_equal(index.statistic, 0.09626774479970557, decimal=4)
 
 
 if __name__ == '__main__':
